use axum::Extension;
use domain::dto::feedback::FeedbackAdd;
use domain::dto::pageable::PageParams;
use domain::vo::feedback::FeedbackPageable;
use library::context::Context;
use library::model::response::ResResult;
use library::validator::body_validator::JsonBody;
use library::validator::query_validator::QueryParams;

use crate::service;

/// post: /feedback
///
/// 添加反馈信息
pub async fn add_feedback(
    Extension(context): Extension<Context>,
    JsonBody(req): JsonBody<FeedbackAdd>,
) -> ResResult<()> {
    service::feedback_service::add_feedback(context, req).await
}

/// get: /feedback
///
/// 获取反馈信息列表
pub async fn get_feedback_list_by_page(
    Extension(context): Extension<Context>,
    QueryParams(page_params): QueryParams<PageParams>,
) -> ResResult<FeedbackPageable> {
    service::feedback_service::get_feedback_list_by_page(
        context,
        page_params.page.unwrap(),
        page_params.page_size.unwrap(),
    )
    .await
}